<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package rubik-theme
 */

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">

	<header id="masthead" class="site-header">
        <div class="container">
            <div class="logo">
                <?php
                if ( get_theme_mod( 'custom_logo' ) ) : ?>
                    <a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
                        <?php
                            $custom_logo_id = get_theme_mod( 'custom_logo' );
                            $image = wp_get_attachment_image_src( $custom_logo_id , 'full' );
                        ?>
                        <img src="<?php echo $image[0]; ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" >
                    </a>
                <?php else : ?>
                    <a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a>
                <?php endif; ?>
            </div>
            <div class="menu">
                <?php
                wp_nav_menu( array(
                    'menu_id'        => 'primary-menu',
                ) );
                ?>
            </div>
            <div class="mobile-menu"><i class="fa fa-bars"></i></div>
        </div>
	</header><!-- #masthead -->

    <?php if(is_front_page()) : ?>
        <?php get_template_part( 'template-parts/slider' ); ?>
    <?php else : ?>
        <div class="intro-page" <?php if(get_the_post_thumbnail_url()) : ?>style="background-image: url(<?php the_post_thumbnail_url('full') ?>)"<?php else : ?> style="background-image: url(<?php echo get_template_directory_uri() ?>/img/slider.jpg)" <?php endif; ?>>
            <div class="container">
                <?php
                    $post = $wp_query->get_queried_object();
                    $pagename = $post->post_title;
                    $pagedesc = $post->post_excerpt;
                ?>
                <h1><?php echo $pagename; ?></h1>
                <p><?php echo $pagedesc; ?></p>
            </div>
        </div>
    <?php endif; ?>

	<div id="content" class="wrapper">
